Hi there!

Thanks for suggesting a new feature for the pipeline! Please delete this text and anything that's not relevant from the template below:

#### Is your feature request related to a problem? Please describe.
A clear and concise description of what the problem is.
Ex. I'm always frustrated when [...]

#### Describe the solution you'd like
A clear and concise description of what you want to happen.

#### Describe alternatives you've considered
A clear and concise description of any alternative solutions or features you've considered.

#### Additional context
Add any other context about the feature request here.
